@@ -68,12 +68,16 @@ if (opt$ncpus == "getOption") {
     opt$ncpus <- max(1L, parallel::detectCores())
 }
 
+## ensure installation is stripped
+Sys.setenv("_R_SHLIB_STRIP_"="true")
+
 install_packages2 <- function(pkgs, ..., error = FALSE, skipinstalled = FALSE) {
     e <- NULL
     capture <- function(e) {
         if (error) {
             catch <-
-                grepl("package.*(is|are) not available", e$message) ||
+                grepl("download of package .* failed", e$message) ||
+                grepl("(dependenc|package).*(is|are) not available", e$message) ||
                 grepl("installation of package.*had non-zero exit status", e$message)
             if (catch) {
                 e <<- e
